summaryrefslogtreecommitdiff
path: root/src/mongo/s/range_arithmetic.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/range_arithmetic.h')
-rw-r--r--src/mongo/s/range_arithmetic.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/s/range_arithmetic.h b/src/mongo/s/range_arithmetic.h
index a1f0f440554..d13683be70b 100644
--- a/src/mongo/s/range_arithmetic.h
+++ b/src/mongo/s/range_arithmetic.h
@@ -111,12 +111,12 @@ namespace mongo {
* NOTE: For overlap testing to work correctly, there may be no overlaps present in the map
* itself.
*/
- typedef map<BSONObj, BSONObj, BSONObjCmp> RangeMap;
+ typedef std::map<BSONObj, BSONObj, BSONObjCmp> RangeMap;
/**
* A RangeVector is a list of [lower,upper) ranges.
*/
- typedef vector<pair<BSONObj,BSONObj> > RangeVector;
+ typedef std::vector<std::pair<BSONObj,BSONObj> > RangeVector;
/**
* Returns the overlap of a range [inclusiveLower, exclusiveUpper) with the provided range map
@@ -144,13 +144,13 @@ namespace mongo {
const BSONObj& exclusiveUpper );
/**
* String representation of [inclusiveLower, exclusiveUpper)
*/
std::string rangeToString( const BSONObj& inclusiveLower,
const BSONObj& exclusiveUpper );
/**
* String representation of overlapping ranges as a list "[range1),[range2),..."
*/
std::string overlapToString( RangeVector overlap );
@@ -144,13 +144,13 @@ namespace mongo {
const BSONObj& exclusiveUpper );
/**
- * String representation of [inclusiveLower, exclusiveUpper)
+ * std::string representation of [inclusiveLower, exclusiveUpper)
*/
std::string rangeToString( const BSONObj& inclusiveLower,
@@ -144,13 +144,13 @@ namespace mongo {
const BSONObj& exclusiveUpper );
/**
- * String representation of overlapping ranges as a list "[range1),[range2),..."
+ * std::string representation of overlapping ranges as a list "[range1),[range2),..."
*/
std::string overlapToString( RangeVector overlap );